@@ -1,7 +1,7 @@
 Pkl.Hajek.s <- function(VecPk.s)
 {
   if(! is.vector(VecPk.s)     ){stop("VecPk.s must be a vector.")                                                                               }
-  if(any(is.na(VecPk.s))      ){stop("There are missing values in VecPk.s.")                                                                    }
+  if(anyNA(VecPk.s)           ){stop("There are missing values in VecPk.s.")                                                                    }
   if(any(VecPk.s<=0|VecPk.s>1)){stop("There are invalid values in VecPk.s.")                                                                    }
   n                            <- length(VecPk.s)
   if(all(VecPk.s==1)          ){OUTPUT <- rep(1, times= n)                                                                                      }
@@ -9,7 +9,7 @@ Pkl.Hajek.s <- function(VecPk.s)
   {
     OUTPUT                     <- .C("Pkl_Hajek_s",
                                       as.double(VecPk.s),
-                                      as.integer(n),
+                                      n,
                                       VectMatProb = double(n*n),
                                       PACKAGE = "samplingVarEst")$VectMatProb
   }
