@@ -14,15 +14,15 @@ VE.EB.SYG.Ratio <- function(VecY.s, VecX.s, VecPk.s, MatPkl.s, VecAlpha.s = rep(
   if(n != length(VecX.s)                ){stop("The lengths of VecY.s and VecX.s are different.")                                 }
   if(n != length(VecAlpha.s)            ){stop("The lengths of VecY.s and VecAlpha.s are different.")                             }
   if(n != DimMatR                       ){stop("The lengths of VecY.s, VecPk.s and dimensions of MatPkl.s are different.")        }
-  if(any(is.na(VecPk.s))                ){stop("There are missing values in VecPk.s.")                                            }
-  if(any(is.na(VecAlpha.s))             ){stop("There are missing values in VecAlpha.s.")                                         }
+  if(anyNA(VecPk.s)                     ){stop("There are missing values in VecPk.s.")                                            }
+  if(anyNA(VecAlpha.s)                  ){stop("There are missing values in VecAlpha.s.")                                         }
   if(any(VecPk.s<=0|VecPk.s>1)          ){stop("There are invalid values in VecPk.s.")                                            }
   if(any(VecAlpha.s<0)                  ){stop("There are invalid values in VecAlpha.s.")                                         }
   if(any(VecAlpha.s==0)                 ){warning("There are zero values in VecAlpha.s. It is valid, but estimates get unstable.")}
-  if(any(is.na(MatPkl.s))               ){stop("There are missing values in MatPkl.s.")                                           }
+  if(anyNA(MatPkl.s)                    ){stop("There are missing values in MatPkl.s.")                                           }
   if(any(MatPkl.s<=0|MatPkl.s>1)        ){stop("There are invalid values in MatPkl.s.")                                           }
-  if(any(is.na(VecY.s))                 ){stop("There are missing values in VecY.s.")                                             }
-  if(any(is.na(VecX.s))                 ){stop("There are missing values in VecX.s.")                                             }
+  if(anyNA(VecY.s)                      ){stop("There are missing values in VecY.s.")                                             }
+  if(anyNA(VecX.s)                      ){stop("There are missing values in VecX.s.")                                             }
   if(any(VecX.s==0)                     ){warning("There are zero values in the denominator variable VecX.s.")                    }
   VecRhok.s                              <- (1/VecPk.s)^(1-VecAlpha.s)
   VecEstTheta_k                          <- .C("Est_Ratio_Excluding_All_ElementsByRho",
@@ -30,7 +30,7 @@ VE.EB.SYG.Ratio <- function(VecY.s, VecX.s, VecPk.s, MatPkl.s, VecAlpha.s = rep(
                                                 as.double(VecX.s),
                                                 as.double(VecPk.s),
                                                 as.double(VecRhok.s),
-                                                as.integer(n),
+                                                n,
                                                 VectVarEst = double(n),
                                                 PACKAGE = "samplingVarEst")$VectVarEst
   EstTheta                               <- Est.Ratio(VecY.s, VecX.s, VecPk.s)
@@ -39,7 +39,7 @@ VE.EB.SYG.Ratio <- function(VecY.s, VecX.s, VecPk.s, MatPkl.s, VecAlpha.s = rep(
                                                 as.double(VecPseudo.s),
                                                 as.double(VecPk.s),
                                                 as.double(c(MatPkl.s)),
-                                                as.integer(n),
+                                                n,
                                                 VarEst = double(1),
                                                 PACKAGE = "samplingVarEst")$VarEst
   if(OUTPUT<0                           ){warning("The variance estimate contains negative values.")                              }
