@@ -9,12 +9,12 @@ VE.Jk.EB.SW2.RegCo.Hajek <- function(VecY.s, VecX.s, VecPk.s, nII, VecPi.s, VecC
   if(! is.integer(VecCluSize.s)             ){stop("VecCluSize.s must be a vector of integers.")                                                                             }
   if(! is.vector(VecCluLab.s)               ){stop("VecCluLab.s must be a vector.")                                                                                          }
   if(! is.integer(VecCluLab.s)              ){stop("VecCluLab.s must be a vector of integers.")                                                                              }
-  if(any(is.na(VecPk.s))                    ){stop("There are missing values in VecPk.s.")                                                                                   }
+  if(anyNA(VecPk.s)                         ){stop("There are missing values in VecPk.s.")                                                                                   }
   if(any(VecPk.s<=0|VecPk.s>1)              ){stop("There are invalid values in VecPk.s.")                                                                                   }
-  if(any(is.na(VecPi.s))                    ){stop("There are missing values in VecPi.s.")                                                                                   }
+  if(anyNA(VecPi.s)                         ){stop("There are missing values in VecPi.s.")                                                                                   }
   if(any(VecPi.s<=0|VecPi.s>1)              ){stop("There are invalid values in VecPi.s.")                                                                                   }
-  if(any(is.na(VecY.s))                     ){stop("There are missing values in VecY.s.")                                                                                    }
-  if(any(is.na(VecX.s))                     ){stop("There are missing values in VecX.s.")                                                                                    }
+  if(anyNA(VecY.s)                          ){stop("There are missing values in VecY.s.")                                                                                    }
+  if(anyNA(VecX.s)                          ){stop("There are missing values in VecX.s.")                                                                                    }
   if(length(nII) != 1                       ){stop(paste("nII must be a integer scalar, i.e. a vector of length 1 valued from 1 to", as.character(.Machine$integer.max),"."))}
   n                                          <- length(VecY.s)
   VecPi.sI                                   <- VecPi.s[!duplicated(VecCluLab.s)]
@@ -32,9 +32,9 @@ VE.Jk.EB.SW2.RegCo.Hajek <- function(VecY.s, VecX.s, VecPk.s, nII, VecPi.s, VecC
                                                     as.double(VecY.s),
                                                     as.double(VecX.s),
                                                     as.double(VecPk.s),
-                                                    as.integer(n),
-                                                    as.integer(nI),
-                                                    as.double(DoublenI),
+                                                    n,
+                                                    nI,
+                                                    DoublenI,
                                                     as.integer(VecCluLab.s),
                                                     as.integer(VecCluLab.s[!duplicated(VecCluLab.s)]),
                                                     as.double(1 - VecPi.sI),
@@ -46,7 +46,7 @@ VE.Jk.EB.SW2.RegCo.Hajek <- function(VecY.s, VecX.s, VecPk.s, nII, VecPi.s, VecC
                                                     as.double(VecY.s),
                                                     as.double(VecX.s),
                                                     as.double(VecPk.s),
-                                                    as.integer(n),
+                                                    n,
                                                     VectVarEst = double(n),
                                                     PACKAGE = "samplingVarEst")$VectVarEst
   SQVecPseudo.s                              <- ( (n-1)/n * (EstTheta - VecEstTheta_k) )^2
